@@ -371,7 +371,9 @@ class FilesOpenItem(FileSaveItem):
     def check_value(self, value):
         """Override DataItem method"""
         if not self.get_prop('data', 'check_value', True):
-            return True 
+            return True
+        if value is None:
+            return False
         allexist = True
         for path in value:
             allexist = allexist and os.path.exists(path) \
@@ -652,14 +654,20 @@ class DictItem(ButtonItem):
     def __init__(self, label, default=None, help='', check=True):
         def dictedit(instance, item, value, parent):
             try:
-                # Spyder 3
-                from spyderlib.widgets.variableexplorer \
+                # Spyder 3.0
+                from spyder.widgets.variableexplorer \
                     import collectionseditor
                 Editor = collectionseditor.CollectionsEditor
             except ImportError:
-                # Spyder 2
-                from spyderlib.widgets import dicteditor
-                Editor = dicteditor.DictEditor
+                try:
+                    # Spyder 3.0-
+                    from spyderlib.widgets.variableexplorer \
+                        import collectionseditor
+                    Editor = collectionseditor.CollectionsEditor
+                except ImportError:
+                    # Spyder 2
+                    from spyderlib.widgets import dicteditor
+                    Editor = dicteditor.DictEditor
             editor = Editor(parent)
             value_was_none = value is None
             if value_was_none:
@@ -682,4 +690,4 @@ class FontFamilyItem(StringItem):
         * default [string]: default value (optional)
         * help [string]: text shown in tooltip (optional)
     """
-    pass
\ No newline at end of file
+    pass
