@@ -842,11 +842,15 @@ class FloatArrayWidget(AbstractDataSetWidget):
         parent = self.parent_layout.parent
         label = self.item.get_prop_value("display", "label")
         try:
-            # Spyder 3
-            from spyderlib.widgets.variableexplorer import arrayeditor
+            # Spyder 3.0
+            from spyder.widgets.variableexplorer import arrayeditor
         except ImportError:
-            # Spyder 2
-            from spyderlib.widgets import arrayeditor
+            # Spyder 3.0-
+            try:
+                from spyderlib.widgets.variableexplorer import arrayeditor
+            except ImportError:
+                # Spyder 2
+                from spyderlib.widgets import arrayeditor
         editor = arrayeditor.ArrayEditor(parent)
         if editor.setup_and_check(self.arr, title=label):
             if editor.exec_():
