@@ -14,8 +14,10 @@ import os
 import os.path as osp
 import subprocess
 
-from spyderlib.widgets.sourcecode.codeeditor import CodeEditor
-
+try:  # Spyder3.0
+    from spyder.widgets.sourcecode.codeeditor import CodeEditor
+except ImportError:
+    from spyderlib.widgets.sourcecode.codeeditor import CodeEditor
 # Local imports
 from guidata.qt.QtGui import (QWidget, QVBoxLayout, QSplitter, QFont,
                               QListWidget, QPushButton, QLabel, QGroupBox,
