@@ -20,7 +20,8 @@ import numpy as np
 from guidata.utils import utf8_to_unicode
 from guidata.userconfigio import BaseIOHandler, WriterMixin
 
-from guidata.py3compat import to_text_string, PY3, is_binary_string, to_binary_string
+from guidata.py3compat import (PY2, PY3, is_binary_string, to_binary_string,
+                               to_text_string)
 
 
 class TypeConverter(object):
@@ -42,8 +43,11 @@ class TypeConverter(object):
         return self._from_type(value)
 
 
-#TODO: Py3/Test if the 'unicode_hdf' type converter is working with Python 3
-unicode_hdf = TypeConverter(lambda x: x.encode("utf-8"), utf8_to_unicode)
+if PY2:
+    unicode_hdf = TypeConverter(lambda x: x.encode("utf-8"), utf8_to_unicode)
+else:
+    unicode_hdf = TypeConverter(lambda x: x.encode("utf-8"), 
+                                lambda x: to_text_string(x, encoding='utf-8'))
 int_hdf = TypeConverter(int)
 
 
@@ -359,7 +363,7 @@ class HDF5Reader(HDF5Handler):
             count = len(ids)
             for idx, name in enumerate(ids):
                 if progress_callback is not None:
-                    if progress_callback(int(100*float(idx)/(count-1))):
+                    if progress_callback(int(100*float(idx)/count)):
                         break
                 with self.group(name):
                     group = self.get_parent_group()
