@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright © 2011 Pierre Raybaut
+# Copyright © 2011-2012 Pierre Raybaut
 # Licensed under the terms of the MIT License
 # (see spyderlib/__init__.py for details)
 
@@ -17,13 +17,19 @@ This module should be fully compatible with:
     * PySide
 """
 
-import os, sys
+from __future__ import print_function
+
+import os
+import sys
+import collections
 
 from guidata.qt.QtGui import QFileDialog
 
-#===============================================================================
+from guidata.py3compat import is_text_string, to_text_string, TEXT_TYPES
+
+#==============================================================================
 # QVariant conversion utilities
-#===============================================================================
+#==============================================================================
 
 PYQT_API_1 = False
 if os.environ['QT_API'] == 'pyqt':
@@ -50,8 +56,8 @@ if os.environ['QT_API'] == 'pyqt':
         to PyQt API #2 and Pyside (QVariant does not exist)"""
         if PYQT_API_1:
             # PyQt API #1
-            assert callable(convfunc)
-            if convfunc in (unicode, str):
+            assert isinstance(convfunc, collections.Callable)
+            if convfunc in TEXT_TYPES or convfunc is to_text_string:
                 return convfunc(qobj.toString())
             elif convfunc is bool:
                 return qobj.toBool()
@@ -65,20 +71,20 @@ if os.environ['QT_API'] == 'pyqt':
             # PyQt API #2
             return qobj
 else:
-    def to_qvariant(obj=None):
+    def to_qvariant(obj=None):  # analysis:ignore
         """Convert Python object to QVariant
         This is a transitional function from PyQt API#1 (QVariant exist) 
         to PyQt API#2 and Pyside (QVariant does not exist)"""
         return obj
-    def from_qvariant(qobj=None, pytype=None):
+    def from_qvariant(qobj=None, pytype=None):  # analysis:ignore
         """Convert QVariant object to Python object
         This is a transitional function from PyQt API #1 (QVariant exist) 
         to PyQt API #2 and Pyside (QVariant does not exist)"""
         return qobj
 
-#===============================================================================
+#==============================================================================
 # Wrappers around QFileDialog static methods
-#===============================================================================
+#==============================================================================
 
 def getexistingdirectory(parent=None, caption='', basedir='',
                          options=QFileDialog.ShowDirsOnly):
@@ -96,9 +102,9 @@ def getexistingdirectory(parent=None, caption='', basedir='',
         if sys.platform == "win32":
             # On Windows platforms: restore standard outputs
             sys.stdout, sys.stderr = _temp1, _temp2
-    if not isinstance(result, basestring):
+    if not is_text_string(result):
         # PyQt API #1
-        result = unicode(result)
+        result = to_text_string(result)
     return result
 
 def _qfiledialog_wrapper(attr, parent=None, caption='', basedir='',
@@ -110,7 +116,7 @@ def _qfiledialog_wrapper(attr, parent=None, caption='', basedir='',
         from guidata.qt.QtCore import QString
     except ImportError:
         # PySide or PyQt >=v4.6
-        QString = None
+        QString = None  # analysis:ignore
     tuple_returned = True
     try:
         # PyQt >=v4.6
@@ -130,6 +136,12 @@ def _qfiledialog_wrapper(attr, parent=None, caption='', basedir='',
     try:
         result = func(parent, caption, basedir,
                       filters, selectedfilter, options)
+    except TypeError:
+        # The selectedfilter option (`initialFilter` in Qt) has only been 
+        # introduced in Jan. 2010 for PyQt v4.7, that's why we handle here 
+        # the TypeError exception which will be raised with PyQt v4.6
+        # (see Issue 960 for more details)
+        result = func(parent, caption, basedir, filters, options)
     finally:
         if sys.platform == "win32":
             # On Windows platforms: restore standard outputs
@@ -144,13 +156,13 @@ def _qfiledialog_wrapper(attr, parent=None, caption='', basedir='',
         output = result
     if QString is not None:
         # PyQt API #1: conversions needed from QString/QStringList
-        selectedfilter = unicode(selectedfilter)
+        selectedfilter = to_text_string(selectedfilter)
         if isinstance(output, QString):
             # Single filename
-            output = unicode(output)
+            output = to_text_string(output)
         else:
             # List of filenames
-            output = [unicode(fname) for fname in output]
+            output = [to_text_string(fname) for fname in output]
             
     # Always returns the tuple (output, selectedfilter)
     return output, selectedfilter
@@ -191,8 +203,8 @@ def getsavefilename(parent=None, caption='', basedir='', filters='',
 if __name__ == '__main__':
     import guidata
     _app = guidata.qapplication()
-    print repr(getexistingdirectory())
-    print repr(getopenfilename(filters='*.py;;*.txt'))
-    print repr(getopenfilenames(filters='*.py;;*.txt'))
-    print repr(getsavefilename(filters='*.py;;*.txt'))
-    import sys; sys.exit()
+    print(repr(getexistingdirectory()))
+    print(repr(getopenfilename(filters='*.py;;*.txt')))
+    print(repr(getopenfilenames(filters='*.py;;*.txt')))
+    print(repr(getsavefilename(filters='*.py;;*.txt')))
+    sys.exit()
