@@ -12,9 +12,11 @@ DataSet objects may be grouped into DataSetGroup, allowing them to be edited
 in a single dialog box (with one tab per DataSet object).
 """
 
+from __future__ import print_function
+
 SHOW = True # Show test in GUI-based test launcher
 
-from all_features import TestParameters
+from guidata.tests.all_features import TestParameters
 from guidata.dataset.datatypes import DataSetGroup
 
 if __name__ == "__main__":
@@ -24,7 +26,7 @@ if __name__ == "__main__":
 
     e1 = TestParameters("DataSet #1")
     e2 = TestParameters("DataSet #2")
-    g = DataSetGroup( [e1,e2], title='Parameters group' )
+    g = DataSetGroup( [e1, e2], title='Parameters group' )
     g.edit()
-    print e1
+    print(e1)
     g.edit()
