@@ -12,9 +12,11 @@ From time to time, it may be useful to derive a DataSet from another. The main
 application is to extend a parameter set with additionnal parameters.
 """
 
+from __future__ import print_function
+
 SHOW = True # Show test in GUI-based test launcher
 
-from all_features import TestParameters
+from guidata.tests.all_features import TestParameters
 from guidata.dataset.datatypes import BeginGroup, EndGroup
 from guidata.dataset.dataitems import FloatItem, BoolItem
 
@@ -35,4 +37,4 @@ if __name__ == '__main__':
     
     e = TestParameters2()
     e.edit()
-    print e
+    print(e)
